==> pls-3.1.0.tar.gz: pls-3.1.0/README.md <==
<h1 align="center">
  <img height="128px" src="https://raw.githubusercontent.com/dhruvkb/pls/main/readme_assets/pls.svg"/>

  <p align="center">
    <a href="https://www.python.org">
      <img src="https://img.shields.io/pypi/pyversions/pls" alt="Python versions"/>
    </a>
    <a href="https://github.com/dhruvkb/pls/blob/main/LICENSE">
      <img src="https://img.shields.io/github/license/dhruvkb/pls" alt="GPL-3.0"/>
    </a>
    <a href="https://pypi.org/project/pls/">
      <img src="https://img.shields.io/static/v1?label=supported%20OS&message=posix,%20win&color=informational" alt="Platforms"/>
    </a>
    <a href="https://github.com/dhruvkb/pls/actions/workflows/ci.yml">
      <img src="https://github.com/dhruvkb/pls/actions/workflows/ci.yml/badge.svg" alt="CI status"/>
    </a>
  </p>
</h1>

<p align="center">
  <strong>Links:</strong>
</p>
<p align="center">
  <a href="https://pypi.org/project/pls/">
    <img src="https://img.shields.io/pypi/v/pls" alt="pls on PyPI"/>
  </a>
  <a href="https://dhruvkb.github.io/pls/">
    <img src="https://img.shields.io/static/v1?label=docs&message=dhruvkb/pls:docs&color=informational" alt="Docs"/>
  </a>
</p>

<p align="center">
  <img src="https://raw.githubusercontent.com/dhruvkb/pls/main/readme_assets/demo.png" alt="Demo of `pls`"/>
</p>

`pls` is a prettier and powerful `ls` for the pros.

The "p" stands for
- pretty (the output from `pls` surely looks better)
- powerful (`pls` has lots of features and endless customisation)
- programmer (`pls` is geared towards developers)
- professional (`pls` can be extensively tweaked by the pros)
- Python (`pls` is written in Python!)

Just pick whichever helps you remember the command name.

It works in a manner similar to `ls`, in  that it lists directories and files in
a given directory, but it adds many more
[developer-friendly features](https://dhruvkb.github.io/pls/features).

> ⚠️ Note that `pls` is not a replacement for `ls`. `ls` is a tried, tested and
trusted command with lots of features. `pls`, on the other hand, is a simple
tool for people who just want to see the contents of their directories.

## Documentation

We have some very beautiful [documentation](https://dhruvkb.github.io/pls) over
on our GitHub pages site. These docs are built from the
[`docs` branch](https://github.com/dhruvkb/pls/tree/docs) in the same
repository, and contributions to the docs are most welcome.

The docs contain information on almost everything, including but not limited to
the following:

- [installation, updates and usage](https://dhruvkb.github.io/pls/get_started)
- [features and CLI options](https://dhruvkb.github.io/pls/features)
- [reference](https://dhruvkb.github.io/pls/reference)
- [contribution](https://dhruvkb.github.io/pls/contribution)

==> pls-4.0.2.tar.gz: pls-4.0.2/README.md <==
<h1 align="center">
  <img height="128px" src="https://raw.githubusercontent.com/dhruvkb/pls/main/readme_assets/pls.svg"/>

  <p align="center">
    <a href="https://www.python.org">
      <img src="https://img.shields.io/pypi/pyversions/pls" alt="Python versions"/>
    </a>
    <a href="https://github.com/dhruvkb/pls/blob/main/LICENSE">
      <img src="https://img.shields.io/github/license/dhruvkb/pls" alt="GPL-3.0"/>
    </a>
    <a href="https://pypi.org/project/pls/">
      <img src="https://img.shields.io/static/v1?label=supported%20OS&message=posix,%20win&color=informational" alt="Platforms"/>
    </a>
    <a href="https://github.com/dhruvkb/pls/actions/workflows/ci.yml">
      <img src="https://github.com/dhruvkb/pls/actions/workflows/ci.yml/badge.svg" alt="CI status"/>
    </a>
  </p>
</h1>

<p align="center">
  <strong>Links:</strong>
</p>
<p align="center">
  <a href="https://pypi.org/project/pls/">
    <img src="https://img.shields.io/pypi/v/pls" alt="pls on PyPI"/>
  </a>
  <a href="https://dhruvkb.github.io/pls/">
    <img src="https://img.shields.io/static/v1?label=docs&message=dhruvkb/pls:docs&color=informational" alt="Docs"/>
  </a>
</p>

<p align="center">
  <img src="https://raw.githubusercontent.com/dhruvkb/pls/main/readme_assets/demo.png" alt="Demo of `pls`"/>
  <img src="https://raw.githubusercontent.com/dhruvkb/pls/main/readme_assets/help.png" alt="Help of `pls`"/>
</p>

`pls` is a prettier and powerful `ls` for the pros.

The "p" stands for
- pretty (the output from `pls` surely looks better)
- powerful (`pls` has lots of features and endless customisation)
- programmer (`pls` is geared towards developers)
- professional (`pls` can be extensively tweaked by the pros)
- Python (`pls` is written in Python!)

Just pick whichever helps you remember the command name.

It works in a manner similar to `ls`, in  that it lists directories and files in
a given directory, but it adds many more
[developer-friendly features](https://dhruvkb.github.io/pls/features).

> ⚠️ Note that `pls` is not a replacement for `ls`. `ls` is a tried, tested and
trusted command with lots of features. `pls`, on the other hand, is a simple
tool for people who just want to see the contents of their directories.

## Documentation

We have some very beautiful [documentation](https://dhruvkb.github.io/pls) over
on our GitHub pages site. These docs are built from the
[`docs` branch](https://github.com/dhruvkb/pls/tree/docs) in the same
repository, and contributions to the docs are most welcome.

The docs contain information on almost everything, including but not limited to
the following:

- [installation, updates and usage](https://dhruvkb.github.io/pls/get_started)
- [features and CLI options](https://dhruvkb.github.io/pls/features)
- [reference](https://dhruvkb.github.io/pls/reference)
- [contribution](https://dhruvkb.github.io/pls/contribution)
